(Nav School OOP) ไลบรารี่สำหรับใช้เรียน Python OOO by Nav Engineer
==================================================================

PyPi: https://pypi.org/project/navschool_oop/

Python OOP+ วิธีสร้าง Library เป็นของตัวเอง+ อัพโหลด Package ไปยัง
PyPI.org

โปรแกรมนี้ใช้สำหรับเรียนการเขียนโปรแกรมแบบ OOP
สามารถดูตัวอย่างคลิปวิดีโอที่สอนได้ใน: https://youtu.be/1egtTXUJ3-4

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install navschool_oop

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from navschool_oop import myprofile

   Example:
   my = Profile('Navapol')
   my.company = 'Mastertech'
   my.hobby = ['Youtuber','Reading']

   print(my.name)
   my.show_email()
   my.show_myart()
   my.show_hobby()

   พัฒนาโดย: nav.
   FB: https://web.facebook.com/
   YouTube: https://www.youtube.com/
